from os import environ
import logging

from dotenv import load_dotenv, find_dotenv
from sqlalchemy import exc
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sqlalchemy.ext.declarative import declarative_base
from asc.core.database import settings
from asc.core.database.psql_connection import PSQLConnectionPooling
from asc.exceptions.core import CoreWithoutDatabaseConnect

load_dotenv(find_dotenv())
logging.basicConfig(
	level=logging.DEBUG,
	filename='/srv/asc/debug.log'
)
log = logging
env = environ

env_in_prod = True if env.get('in_production','True') == 'True' else False
env_in_test = True if env.get('in_testing','True') == 'True' else False
can_do_save = True

# Não aplica commits ou operações quando em prd teste.
if env_in_prod and env_in_test:
	can_do_save = False

if environ.get('database__host'):  # Conecta somente quando necessário.
	try:
		with PSQLConnectionPooling() as connection:
			engine = create_engine(**settings.connection_engine, creator=connection.getconn)
			session_factory = sessionmaker(bind=engine)
			Base = declarative_base()

	except exc.DBAPIError as e:
		if e.connection_invalidated:
			print('EE',e)
else:
	raise CoreWithoutDatabaseConnect(environ)