from sqlalchemy.orm import relationship
from sqlalchemy import ForeignKey
from sqlalchemy import TIMESTAMP
from sqlalchemy import Boolean
from sqlalchemy import VARCHAR
from sqlalchemy import ARRAY
from sqlalchemy import JSON
from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import Text

from asc.core.database.model import Model


class MelhorenvioState(Model):
    __tablename__ = 'melhorenvio_state'
    __table_args__ = {'schema': 'private'}

    id_melhorenvio_state = Column(Integer, primary_key=True)
    oauth2_bearer = Column(Text, nullable=False)
    code_refresh = Column(VARCHAR)
    oauth2_code = Column(Text, nullable=False)
    dt_update = Column(TIMESTAMP, nullable=False)
    js_config = Column(JSON)


class Order(Model):
    __tablename__ = 'order'
    __table_args__ = {'schema': 'private'}

    id_order = Column(Integer, primary_key=True)
    id_user = Column(Integer, nullable=False)
    id_order_status = Column(Integer, nullable=False, server_default='7')
    id_shipment = Column(Integer, nullable=False)
    id_order_delivery = Column(ForeignKey('private.order_delivery.id_order_delivery', ondelete='CASCADE', onupdate='RESTRICT'))

    order_id_order_delivery_fkey = relationship('OrderDelivery')


class OrderDelivery(Model):
    __tablename__ = 'order_delivery'
    __table_args__ = {'schema': 'private'}

    id_order_delivery = Column(Integer, primary_key=True)
    id_order_delivery_status = Column(Integer, nullable=False, server_default='0')
    dt_canceled = Column(TIMESTAMP)
    dt_arrived = Column(TIMESTAMP)
    dt_post = Column(TIMESTAMP, nullable=False)
    cd_tracking = Column(VARCHAR(16))
    st_tracking = Column(Integer, nullable=False, server_default='1')
    id_melhorenvio_purchase = Column(VARCHAR(36))
    id_melhorenvio_service = Column(Integer)
    id_melhorenvio_cart = Column(VARCHAR(36))
    cd_melhorenvio_protocol = Column(VARCHAR(54), nullable=False)
    lk_melhorenvio_print = Column(VARCHAR(512))
    ls_product_box = Column(ARRAY(Integer), nullable=False)
    js_address = Column(JSON)
    is_errored = Column(Boolean, nullable=False, server_default='False')


class OrderDeliveryStatus(Model):
    __tablename__ = 'order_delivery_status'
    __table_args__ = {'schema': 'private'}

    id_order_delivery_status = Column(Integer, primary_key=True)
    name = Column(VARCHAR(32), nullable=False)
