from asc.core import env
from asc.core.ABC.APIRequestor import APIRequestor


class APIDigitalOcean(APIRequestor):

    base_api_url = env.get("digitalocean__url_baseapi")
    base_headers = {
        'Authorization': f'Bearer {env.get("digitalocean__api_token")}',
        'User-Agent': f'ASC/APIRequestor',
    }

    def GET_domains(self) -> dict:
        """
        retrieve a list of all of the domains in your account.
        :return:
        """
        return self.read_response(
            self.GET('v2/domains')
        )

    def POST_domains(self, **data) -> dict:
        """
        create a new domain in your account.
        :return:
        """
        return self.read_response(
            self.POST('v2/domains', {
                'name': data.get('name'),
                'ip_address': data.get('ip_address')
            })
        )

    def POST_domains_record(self, domain_name:str, **data) -> dict:
        """
        To create a new record to a domain.
        :return:
        """
        return self.read_response(
            self.POST(f'v2/domains/{domain_name}/records', {
                "name": data.get('name'),
                "data": data.get('data'),
                "type": data.get('type','A'),
                "priority": data.get('priority'),
                "port": data.get('port'),
                "ttl": data.get('ttl',1800),
                "weight": data.get('weight'),
                "flags": data.get('flags'),
                "tag": data.get('tag')
            })
        )
