"""
    extractor.py

    Arquivo responsável por extrair dados dos pedidos já feitos,
    afim de gerar arquivos csv para consultas/analises offline
"""
from typing import List
from datetime import date

from classes.Valor import FDATA_HORA, Valor
from classes.PSQLMain import PSQLMain
from classes.DebugSys import DebugSys
from asc.tools.marketplace.settings import EXTRACTOR_ONLY_PAYEDS
from asc.tools.marketplace import MarketPlaceReader
from asc.tools.marketplace.tax import MarketPlaceTax
    

vlrC = Valor()
debug = DebugSys()
debug.setTag("extractor")


def capture(
    dt_start:date=None,
    dt_end:date=None
    ):

    extractor_data: List[dict] = []

    MPReader = MarketPlaceReader(dt_start=dt_start,dt_end=dt_end)
    MPTax = MarketPlaceTax() 

    where={}

    if EXTRACTOR_ONLY_PAYEDS: 
        where['id_order_status|%d' % PSQLMain.WSQL_MORE_EQUAL]=2
        where['id_order_status|%d' % PSQLMain.WSQL_LESS_EQUAL]=5

    if dt_start and dt_end: 
        where['"order".dt_add|%s' % PSQLMain.WSQL_BETWEEN]=[f'{dt_start} 00:00:00',f'{dt_end} 23:59:59']
    
    MPOrderList = MPReader.get_data(where=where)

    if not MPOrderList:
        return []

    for MPOrder in MPOrderList:
        
        debug.write('MPOrder',MPOrder)
        id_payment_type = MPOrder.get('id_payment_type')
        dt_payment = MPOrder.get('dt_update')

        tp_order_payment = MPReader.\
            get_payment_type_str(id_payment_type=id_payment_type)

        if not tp_order_payment or not dt_payment: continue

        """
        tax = MPTax.get_tax(
            tp_order_payment=tp_order_payment,
            vl_order_total=MPOrder.get('vl_order_total',0)
        )

        extractor_data.append(tax)
        """
        vl_order_tax = int(MPOrder.get('vl_order_tax_pagarme') or 0)
        debug.write("VL ORDER TAX",vl_order_tax)
        vl_order_tax+= int(MPOrder.get('vl_order_tax_marketplace') or 0)
        debug.write("VL ORDER TAX",vl_order_tax)

        dtOrderEntry = vlrC.fromDate(MPOrder.get('dt_add'),FDATA_HORA).split(' ')
        dtOrderPay = vlrC.fromDate(dt_payment,FDATA_HORA).split(' ')

        vl_payment = MPOrder.get('vl_payment',0) or MPOrder.get('vl_order_total')

        orderDict = {
            'id':MPOrder.get('id_order'),
            'dateOp':dtOrderEntry[0],
            'dateOpTime':dtOrderEntry[1],
            'datePay':dtOrderPay[0],
            'datePayTime':dtOrderPay[1],
            'ticket':MPOrder.get('ticket'),
            'name':MPOrder.get('userName'),
            'udoc':MPOrder.get('userUdoc'),
            'vlOrderLiquido':vl_payment / 100,
            'vlOrderBruto':vl_payment / 100,
            'vlTaxes':vl_order_tax / 100,
            'vlTotalTx':0,
            'vlTxCartao':0,
            'vlTxProcCartao':0,
            'vlTxPix':0,
            'vlTxProcPix':0,
            'paymentType':None,
            'status':MPOrder.get('id_order_status'),
        }

        if tp_order_payment == 'card':
            orderDict['vlTxProcCartao'] = .99
            orderDict['vlTxCartao'] = orderDict['vlTaxes']
            orderDict['vlTotalTx']\
                = orderDict['vlTxProcCartao']\
                + orderDict['vlTxCartao']

            orderDict['vlOrderLiquido']\
                = orderDict['vlOrderBruto']\
                - orderDict[f'vlTxProcCartao']\
                - orderDict[f'vlTxCartao']

            orderDict['paymentType'] = 'CC'


        if tp_order_payment == 'pix':
            orderDict['vlTxProcPix'] = 0.0
            orderDict['vlTxPix'] = orderDict['vlTaxes']
            orderDict['vlTotalTx']\
                = orderDict['vlTxProcPix']\
                + orderDict['vlTxPix']
                
            orderDict['vlOrderLiquido']\
                = orderDict['vlOrderBruto']\
                - orderDict[f'vlTxProcPix']\
                - orderDict[f'vlTxPix']

            orderDict['paymentType'] = 'PIX'

        if tp_order_payment == 'ted/doc':
            orderDict['paymentType'] = 'TED/DOC'

        """
            orderDict['vlOrderLiquido']\
                = orderDict['vlOrderBruto']\
                - orderDict[f'vl_tax_{tp_order_payment}_process']\
                - orderDict[f'vl_tax_{tp_order_payment}_installments']
        """
        
        orderDict['vlOrderLiquido'] = round(orderDict['vlOrderLiquido'],2)

        """ CSV LISTs
        extractor_data.append([
            MPOrder.get('ticket'),
            vlrC.fromDate(MPOrder.get('dt_add'),FDATA),
            MPOrder.get('userName'),
            MPOrder.get('userUdoc'),
            MPOrder.get('vl_order_total') / 100,
            vl_order_tax / 100
        ])
        """
        extractor_data.append(orderDict)

    return extractor_data